@@ -15,10 +15,10 @@ class network3_perseus():
 
     def configure_device(self):
         self.get_file_from_hedera()
-        #self.add_file_to_hedera("PRE-CHANGE STATE")
-        #self.pre_change=self.capture_state()
-        self.push_config(self.yaml_contents)
-        #self.post_change=self.capture_state()
+        # self.add_file_to_hedera()
+        # self.pre_change=self.capture_pre_state()
+        # self.push_config(self.yaml_contents)
+        # self.post_change=self.capture_post_state()
 
     def get_file_from_hedera(self):
         client = Client.forTestnet()
@@ -26,10 +26,28 @@ class network3_perseus():
         query = FileContentsQuery()
         hedera_fileId = FileId.fromString(self.fileId)
         contents = query.setFileId(hedera_fileId).execute(client)
-        self.yaml_contents = yaml.safe_load(contents.toStringUtf8())
+        all_yaml = yaml.safe_load(contents.toStringUtf8())
+        items=[]
+        for item, value in all_yaml.items():
+            items.append(item)
+        for item, value in all_yaml[max(items)]:
+            print(value)
 
-    def capture_state(self):
-        self.output = subprocess.run(["python", "call_cli.py", "show running-config"], capture_output=True)
+    def capture_pre_state(self):
+        command="show running-config"
+        self.output = subprocess.run(["python", "call_cli.py", command], capture_output=True)
+        raw_json=self.output.stdout.decode('utf-8')
+        print(raw_json)
+        for line in raw_json.split('\n'):
+            print(line)
+            self.append_file_to_hedera(f"{ line } \n")
+        query = FileInfoQuery().setFileId(self.fileId)
+        info = query.execute(self.client)
+        print("File size according to `FileInfoQuery`: ", info.size)
+
+    def capture_post_state(self):
+        command="show running-config"
+        self.output = subprocess.run(["python", "call_cli.py", command], capture_output=True)
         raw_json=self.output.stdout.decode('utf-8')
         self.append_file_to_hedera("POST-CHANGE STATE")
         for line in raw_json.split('\n'):
@@ -45,11 +63,11 @@ class network3_perseus():
         rendered_intended_config = intended_config_template.render(self.yaml_contents)
         subprocess.run(["python", "cli_configure.py", rendered_intended_config])
 
-    def add_file_to_hedera(self, raw_json):
+    def add_file_to_hedera(self):
         self.client = Client.forTestnet()
         self.client.setOperator(OPERATOR_ID, OPERATOR_PRIVATE_KEY)
         tran = FileCreateTransaction()
-        fileContents = raw_json
+        fileContents = "PRE-CHANGE STATE"
         resp = tran.setKeys(OPERATOR_PRIVATE_KEY.getPublicKey()).setContents(fileContents).setMaxTransactionFee(Hbar(2)).execute(self.client)
         print("nodeId: ",  resp.nodeId.toString())
         self.nodeId = resp.nodeId.toString()
